@@ -22,6 +22,9 @@ class test_obsolete_baselib(common.basetest):
         super(test_obsolete_baselib, self).setUp()
         self.append('.hg/obs.py',
                     "import mercurial.obsolete\n"
+                    "# 3.2 and later\n"
+                    "mercurial.obsolete.isenabled = lambda r, opt: True\n"
+                    "# Dropped in 5.1\n"
                     "mercurial.obsolete._enabled = True")
         self.append('.hg/hgrc','\n[extensions]\nobs=.hg/obs.py')
 
