@@ -1,5 +1,7 @@
-import common, os
+import os
+from tests import common
 import hglib
+from hglib.util import b
 
 class test_paths(common.basetest):
     def test_basic(self):
@@ -11,5 +13,7 @@ class test_paths(common.basetest):
         self.client = hglib.open()
         paths = self.client.paths()
         self.assertEquals(len(paths), 1)
-        self.assertEquals(paths['foo'], os.path.abspath('bar'))
-        self.assertEquals(self.client.paths('foo'), os.path.abspath('bar'))
+        self.assertEquals(paths[b('foo')],
+                          os.path.abspath('bar').encode('latin-1'))
+        self.assertEquals(self.client.paths(b('foo')),
+                          os.path.abspath('bar').encode('latin-1'))
